@@ -8,7 +8,8 @@ def send_to_bank(request, payment):
         if not is_app_installed('aparnik.packages.bankgateways.bmi'):
             raise Exception()
         from aparnik.packages.bankgateways.bmi.views import send_request as bmi_send_request
-        return bmi_send_request(request=request, payment=payment)
+        result = bmi_send_request(request=request, payment=payment)
+        return result
     except:
         pass
     try:
@@ -19,4 +20,4 @@ def send_to_bank(request, payment):
     except:
         pass
 
-    raise Http404
\ No newline at end of file
+    raise Http404
